==> nextcloud-16.0.5.tgz: nextcloud/apps/privacy/l10n/pl.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Prywatność",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Centrum prywatności pokazuje, gdzie są przechowywane Twoje dane i kto może uzyskać do nich dostęp, ponieważ udostępniłeś je lub jesteś administratorem.",
    "Add external admin" : "Dodaj zewnętrznego administratora",
    "Your files are not protected by encryption." : "Twoje pliki nie są chronione przez szyfrowanie.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "Twoje pliki są szyfrowane za pomocą {linkopen}server-side-encryption ↗{linkclose}.",
    "This server is protected with full-disk-encryption." : "Ten serwer jest chroniony za pomocą full-disk-encryption.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "Twoje pliki są szyfrowane za pomocą {linkopen}server-side-encryption ↗{linkclose}. Ponadto ten serwer jest chroniony za pomocą full-disk-encryption.",
    "This server is using full-disk-encryption." : "Ten serwer używa full-disk-encryption.",
    "Your data is located in: " : "Twoje dane znajdują się w: ",
    "The admin hasn't selected the location of the server yet." : "Administrator nie wybrał jeszcze lokalizacji serwera.",
    "Please select a country" : "Wybierz kraj",
    "You don't have any shares with individual users." : "Nie masz żadnych udostępnień dla poszczególnych użytkowników.",
    "Somaliland" : "Somalia",
    "United Arab Emirates" : "Zjednoczone Emiraty Arabskie",
    "Afghanistan" : "Afganistan",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Argentina" : "Argentyna",
    "Austria" : "Austria",
    "Australia" : "Australia",
    "Azerbaijan" : "Azerbejdżan",
    "Bosnia and Herzegowina" : "Bośnia i Hercegowina",
    "Bangladesh" : "Bangladesz",
    "Belgium" : "Belgia",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bułgaria",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Brunei" : "Brunei",
    "Bolivia" : "Boliwia",
    "Brazil" : "Brazylia",
    "Bahamas" : "Bahamy",
    "Bhutan" : "Bhutan",
    "Botswana" : "Botswana",
    "Belarus" : "Białoruś",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Democratic Republic of the Congo" : "Demokratyczna Republika Konga",
    "Central African Republic" : "Republika Środkowoafrykańska",
    "Congo" : "Kongo",
    "Switzerland" : "Szwajcaria",
    "Cote d'Ivoire" : "Wybrzeże Kości Słoniowej",
    "Chile" : "Chile",
    "Cameroon" : "Kamerun",
    "China" : "Chiny",
    "Colombia" : "Kolumbia",
    "Costa Rica" : "Kostaryka",
    "Cuba" : "Kuba",
    "Cyprus" : "Cypr",
    "Czech" : "Czechy",
    "Germany" : "Niemcy",
    "Djibouti" : "Dżibuti",
    "Denmark" : "Dania",
    "Dominican Republic" : "Republika Dominikany",
    "Algeria" : "Algieria",
    "Ecuador" : "Ekwador",
    "Estonia" : "Estonia",
    "Egypt" : "Egipt",
    "West Sahara" : "Sahara Zachodnia",
    "Eritrea" : "Erytrea",
    "Spain" : "Hiszpania",
    "Ethiopia" : "Etiopia",
    "Finland" : "Finlandia",
    "Fiji" : "Fidżi",
    "Falkland Islands" : "Falklandy",
    "France" : "Francja",
    "Gabon" : "Gabon",
    "United Kingdom" : "Zjednoczone Królestwo",
    "Georgia" : "Gruzja",
    "Ghana" : "Ghana",
    "Greenland" : "Grenlandia",
    "Gambia" : "Gambia",
    "Guinea" : "Gwinea",
    "Equatorial Guinea" : "Gwinea Równikowa",
    "Greece" : "Grecja",
    "Guatemala" : "Gwatemala",
    "Guinea-Bissau" : "Gwinea Bissau",
    "Guyana" : "Gujana",
    "Honduras" : "Honduras",
    "Croatia" : "Chorwacja",
    "Haiti" : "Haiti",
    "Hungary" : "Węgry",
    "Indonesia" : "Indonezja",
    "Ireland" : "Irlandia",
    "Israel" : "Izrael",
    "India" : "Indie",
    "Iraq" : "Irak",
    "Iran" : "Iran",
    "Iceland" : "Islandia",
    "Italy" : "Włochy",
    "Jamaica" : "Jamajka",
    "Jordan" : "Jordania",
    "Japan" : "Japonia",
    "Kenya" : "Kenia",
    "Kyrgyzstan" : "Kirgistan",
    "Cambodia" : "Kambodża",
    "North Korea" : "Korea Północna",
    "South Korea" : "Korea Południowa",
    "Kuwait" : "Kuwejt",
    "Kazakhstan" : "Kazachstan",
    "Laos" : "Laos",
    "Lebanon" : "Liban",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Litwa",
    "Luxembourg" : "Luksemburg",
    "Latvia" : "Łotwa",
    "Libya" : "Libia",
    "Morocco" : "Maroko",
    "Moldova" : "Mołdawia",
    "Montenegro" : "Czarnogóra",
    "Madagascar" : "Madagaskar",
    "Macedonia" : "Macedonia",
    "Mali" : "Mali",
    "Myanmar" : "Mjanma",
    "Mongolia" : "Mongolia",
    "Mauritania" : "Mauretania",
    "Malawi" : "Malawi",
    "Mexico" : "Meksyk",
    "Malaysia" : "Malezja",
    "Mozambique" : "Mozambik",
    "Namibia" : "Namibia",
    "New Caledonia" : "Nowa Kaledonia",
    "Niger" : "Niger",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nikaragua",
    "Netherlands" : "Holandia",
    "Norway" : "Norwegia",
    "Nepal" : "Nepal",
    "New Zealand" : "Nowa Zelandia",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "Papua New Guinea" : "Papua Nowa Gwinea",
    "Philippines" : "Filipiny",
    "Pakistan" : "Pakistan",
    "Poland" : "Polska",
    "Puerto Rico" : "Portoryko",
    "Portugal" : "Portugalia",
    "Paraguay" : "Paragwaj",
    "Qatar" : "Katar",
    "Romania" : "Rumunia",
    "Serbia" : "Serbia",
    "Russia" : "Rosja",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Arabia Saudyjska",
    "Solomon Islands" : "Wyspy Salomona",
    "Sudan" : "Sudan",
    "Sweden" : "Szwecja",
    "Singapore" : "Singapur",
    "Slovenia" : "Słowenia",
    "Slovakia" : "Słowacja",
    "Sierra Leone" : "Sierra Leone",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Surinam",
    "South Sudan" : "Południowy Sudan",
    "El Salvador" : "Salwador",
    "Syria" : "Syria",
    "Swaziland" : "Eswatini",
    "Chad" : "Czad",
    "Fr. S. Antarctic Lands" : "Ks. Ziemie S. Antarktyczne",
    "Togo" : "Togo",
    "Thailand" : "Tajlandia",
    "Tajikistan" : "Tadżykistan",
    "Timor-Leste" : "Timor Wschodni",
    "Turkmenistan" : "Turkmenia",
    "Tunisia" : "Tunezja",
    "Turkey" : "Turcja",
    "Trinidad and Tobago" : "Trynidad i Tobago",
    "Taiwan" : "Tajwan",
    "Tanzania" : "Tanzania",
    "Ukraine" : "Ukraina",
    "Uganda" : "Uganda",
    "United States" : "Stany Zjednoczone",
    "Uruguay" : "Urugwaj",
    "Uzbekistan" : "Uzbekistan",
    "Venezuela" : "Wenezuela",
    "Vietnam" : "Wietnam",
    "Vanuatu" : "Vanuatu",
    "Yemen" : "Jemen",
    "South Africa" : "Afryka Południowa",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Your Nextcloud account" : "Twoje konto Nextcloud",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Twoje dane reprezentują Ciebie, które mogą być w łatwy sposób nadużywane. W Nextcloud wierzymy, że masz prawo decydować o tym, co dzieje się z Twoimi danymi. Nextcloud chroni Twoje prawa zgodnie z definicją w User Data Manifesto!",
    "User Data Manifesto 2.0" : "User Data Manifesto 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "Określenie podstawowych praw do kontroli własnych danych w dobie internetu",
    "Control" : "Kontrola",
    "over user data access" : "dostęp do danych użytkownika",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Dane jawnie i dobrowolnie przesłane przez użytkownika powinny być pod ostateczną kontrolą użytkownika. Użytkownicy powinni mieć możliwość decydowania, komu przyznać bezpośredni dostęp do swoich danych oraz jakie pozwolenia powinny zostać przyznane.",
    "Knowledge" : "Wiedza",
    "of how the data is stored" : "sposób przechowywania danych",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Kiedy dane są przesyłane do określonego usługodawcy, użytkownicy powinni być informowani o tym, gdzie dany dostawca usług przechowuje dane, jak długo, w jakiej jurysdykcji działa dany usługodawca, i które przepisy mają zastosowanie.",
    "Freedom" : "Dowolność",
    "to choose a platform" : "wybór platformy",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Użytkownicy powinni mieć zawsze możliwość wyodrębnienia swoich danych z usługi w dowolnym czasie, bez możliwości zablokowania przez dostawcę. Aby to zagwarantować, niezbędne są otwarte standardy formatów i protokołów.",
    "Learn more ↗" : "Dowiedz się więcej ↗",
    "Where is your data?" : "Gdzie są Twoje dane?",
    "Who has access to your data?" : "Kto ma dostęp do Twoich danych?",
    "Administrators" : "Administratorzy",
    "People you shared with" : "Osoby, którym udostępniasz",
    "Privacy policy" : "Polityka prywatności",
    "Read the privacy policy." : "Przeczytaj politykę prywatności.",
    "Encryption" : "Szyfrowanie"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> nextcloud-18.0.3.tgz: nextcloud/apps/privacy/l10n/pl.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Prywatność",
    "-" : "-",
    "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Centrum prywatności pokazuje, gdzie są przechowywane Twoje dane i kto może uzyskać do nich dostęp, ponieważ udostępniłeś je lub jesteś administratorem.",
    "Remove external admin" : "Usuń zewnętrznego administratora",
    "Add external admin" : "Dodaj zewnętrznego administratora",
    "Your files are not protected by encryption." : "Twoje pliki nie są chronione przez szyfrowanie.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}." : "Twoje pliki są szyfrowane za pomocą {linkopen}server-side-encryption ↗{linkclose}.",
    "This server is protected with full-disk-encryption." : "Ten serwer jest chroniony za pomocą full-disk-encryption.",
    "Your files are encrypted with {linkopen}server-side-encryption ↗{linkclose}. Additionally, this server is protected with full-disk-encryption." : "Twoje pliki są szyfrowane za pomocą {linkopen}server-side-encryption ↗{linkclose}. Ponadto ten serwer jest chroniony za pomocą full-disk-encryption.",
    "This server is using full-disk-encryption." : "Ten serwer używa full-disk-encryption.",
    "Change data location" : "Zmień dane lokalizacji",
    "Your data is located in: " : "Twoje dane znajdują się w: ",
    "The admin hasn't selected the location of the server yet." : "Administrator nie wybrał jeszcze lokalizacji serwera.",
    "Please select a country" : "Wybierz kraj",
    "You don't have any shares with individual users." : "Nie masz żadnych udostępnień dla poszczególnych użytkowników.",
    "Somaliland" : "Somalia",
    "United Arab Emirates" : "Zjednoczone Emiraty Arabskie",
    "Afghanistan" : "Afganistan",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Argentina" : "Argentyna",
    "Austria" : "Austria",
    "Australia" : "Australia",
    "Azerbaijan" : "Azerbejdżan",
    "Bosnia and Herzegowina" : "Bośnia i Hercegowina",
    "Bangladesh" : "Bangladesz",
    "Belgium" : "Belgia",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bułgaria",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Brunei" : "Brunei",
    "Bolivia" : "Boliwia",
    "Brazil" : "Brazylia",
    "Bahamas" : "Bahamy",
    "Bhutan" : "Bhutan",
    "Botswana" : "Botswana",
    "Belarus" : "Białoruś",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Democratic Republic of the Congo" : "Demokratyczna Republika Konga",
    "Central African Republic" : "Republika Środkowoafrykańska",
    "Congo" : "Kongo",
    "Switzerland" : "Szwajcaria",
    "Cote d'Ivoire" : "Wybrzeże Kości Słoniowej",
    "Chile" : "Chile",
    "Cameroon" : "Kamerun",
    "China" : "Chiny",
    "Colombia" : "Kolumbia",
    "Costa Rica" : "Kostaryka",
    "Cuba" : "Kuba",
    "Cyprus" : "Cypr",
    "Czech" : "Czechy",
    "Germany" : "Niemcy",
    "Djibouti" : "Dżibuti",
    "Denmark" : "Dania",
    "Dominican Republic" : "Republika Dominikany",
    "Algeria" : "Algieria",
    "Ecuador" : "Ekwador",
    "Estonia" : "Estonia",
    "Egypt" : "Egipt",
    "West Sahara" : "Sahara Zachodnia",
    "Eritrea" : "Erytrea",
    "Spain" : "Hiszpania",
    "Ethiopia" : "Etiopia",
    "Finland" : "Finlandia",
    "Fiji" : "Fidżi",
    "Falkland Islands" : "Falklandy",
    "France" : "Francja",
    "Gabon" : "Gabon",
    "United Kingdom" : "Zjednoczone Królestwo",
    "Georgia" : "Gruzja",
    "Ghana" : "Ghana",
    "Greenland" : "Grenlandia",
    "Gambia" : "Gambia",
    "Guinea" : "Gwinea",
    "Equatorial Guinea" : "Gwinea Równikowa",
    "Greece" : "Grecja",
    "Guatemala" : "Gwatemala",
    "Guinea-Bissau" : "Gwinea Bissau",
    "Guyana" : "Gujana",
    "Honduras" : "Honduras",
    "Croatia" : "Chorwacja",
    "Haiti" : "Haiti",
    "Hungary" : "Węgry",
    "Indonesia" : "Indonezja",
    "Ireland" : "Irlandia",
    "Israel" : "Izrael",
    "India" : "Indie",
    "Iraq" : "Irak",
    "Iran" : "Iran",
    "Iceland" : "Islandia",
    "Italy" : "Włochy",
    "Jamaica" : "Jamajka",
    "Jordan" : "Jordania",
    "Japan" : "Japonia",
    "Kenya" : "Kenia",
    "Kyrgyzstan" : "Kirgistan",
    "Cambodia" : "Kambodża",
    "North Korea" : "Korea Północna",
    "South Korea" : "Korea Południowa",
    "Kuwait" : "Kuwejt",
    "Kazakhstan" : "Kazachstan",
    "Laos" : "Laos",
    "Lebanon" : "Liban",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Litwa",
    "Luxembourg" : "Luksemburg",
    "Latvia" : "Łotwa",
    "Libya" : "Libia",
    "Morocco" : "Maroko",
    "Moldova" : "Mołdawia",
    "Montenegro" : "Czarnogóra",
    "Madagascar" : "Madagaskar",
    "Macedonia" : "Macedonia",
    "Mali" : "Mali",
    "Myanmar" : "Mjanma",
    "Mongolia" : "Mongolia",
    "Mauritania" : "Mauretania",
    "Malawi" : "Malawi",
    "Mexico" : "Meksyk",
    "Malaysia" : "Malezja",
    "Mozambique" : "Mozambik",
    "Namibia" : "Namibia",
    "New Caledonia" : "Nowa Kaledonia",
    "Niger" : "Niger",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nikaragua",
    "Netherlands" : "Holandia",
    "Norway" : "Norwegia",
    "Nepal" : "Nepal",
    "New Zealand" : "Nowa Zelandia",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "Papua New Guinea" : "Papua Nowa Gwinea",
    "Philippines" : "Filipiny",
    "Pakistan" : "Pakistan",
    "Poland" : "Polska",
    "Puerto Rico" : "Portoryko",
    "Portugal" : "Portugalia",
    "Paraguay" : "Paragwaj",
    "Qatar" : "Katar",
    "Romania" : "Rumunia",
    "Serbia" : "Serbia",
    "Russia" : "Rosja",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Arabia Saudyjska",
    "Solomon Islands" : "Wyspy Salomona",
    "Sudan" : "Sudan",
    "Sweden" : "Szwecja",
    "Singapore" : "Singapur",
    "Slovenia" : "Słowenia",
    "Slovakia" : "Słowacja",
    "Sierra Leone" : "Sierra Leone",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Surinam",
    "South Sudan" : "Południowy Sudan",
    "El Salvador" : "Salwador",
    "Syria" : "Syria",
    "Swaziland" : "Eswatini",
    "Chad" : "Czad",
    "Fr. S. Antarctic Lands" : "Ks. Ziemie S. Antarktyczne",
    "Togo" : "Togo",
    "Thailand" : "Tajlandia",
    "Tajikistan" : "Tadżykistan",
    "Timor-Leste" : "Timor Wschodni",
    "Turkmenistan" : "Turkmenia",
    "Tunisia" : "Tunezja",
    "Turkey" : "Turcja",
    "Trinidad and Tobago" : "Trynidad i Tobago",
    "Taiwan" : "Tajwan",
    "Tanzania" : "Tanzania",
    "Ukraine" : "Ukraina",
    "Uganda" : "Uganda",
    "United States" : "Stany Zjednoczone",
    "Uruguay" : "Urugwaj",
    "Uzbekistan" : "Uzbekistan",
    "Venezuela" : "Wenezuela",
    "Vietnam" : "Wietnam",
    "Vanuatu" : "Vanuatu",
    "Yemen" : "Jemen",
    "South Africa" : "Afryka Południowa",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Your Nextcloud account" : "Twoje konto Nextcloud",
    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Twoje dane reprezentują Ciebie, które mogą być w łatwy sposób nadużywane. W Nextcloud wierzymy, że masz prawo decydować o tym, co dzieje się z Twoimi danymi. Nextcloud chroni Twoje prawa zgodnie z definicją w User Data Manifesto!",
    "User Data Manifesto 2.0" : "User Data Manifesto 2.0",
    "Defining basic rights for people to control their own data in the internet age" : "Określenie podstawowych praw do kontroli własnych danych w dobie internetu",
    "Control" : "Kontrola",
    "over user data access" : "dostęp do danych użytkownika",
    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Dane jawnie i dobrowolnie przesłane przez użytkownika powinny być pod ostateczną kontrolą użytkownika. Użytkownicy powinni mieć możliwość decydowania, komu przyznać bezpośredni dostęp do swoich danych oraz jakie pozwolenia powinny zostać przyznane.",
    "Knowledge" : "Wiedza",
    "of how the data is stored" : "sposób przechowywania danych",
    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Kiedy dane są przesyłane do określonego usługodawcy, użytkownicy powinni być informowani o tym, gdzie dany dostawca usług przechowuje dane, jak długo, w jakiej jurysdykcji działa dany usługodawca, i które przepisy mają zastosowanie.",
    "Freedom" : "Dowolność",
    "to choose a platform" : "wybór platformy",
    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Użytkownicy powinni mieć zawsze możliwość wyodrębnienia swoich danych z usługi w dowolnym czasie, bez możliwości zablokowania przez dostawcę. Aby to zagwarantować, niezbędne są otwarte standardy formatów i protokołów.",
    "Learn more ↗" : "Dowiedz się więcej ↗",
    "Where is your data?" : "Gdzie są Twoje dane?",
    "Who has access to your data?" : "Kto ma dostęp do Twoich danych?",
    "Administrators" : "Administratorzy",
    "People you shared with" : "Osoby, którym udostępniasz",
    "Privacy policy" : "Polityka prywatności",
    "Read the privacy policy." : "Przeczytaj politykę prywatności.",
    "Encryption" : "Szyfrowanie"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
